@@ -8,7 +8,9 @@ our @ISA = qw( HTTP::Server::PSGI );
 
 use Socket qw(IPPROTO_TCP TCP_NODELAY);
 
-our $VERSION = '0.23_07';
+our $VERSION = '0.23_08';
+
+use Devel::hdb::Logger qw(log);
 
 sub new {
     my($class, %args) = @_;
@@ -35,6 +37,7 @@ sub accept_loop {
     while (1) {
         local $SIG{PIPE} = 'IGNORE';
         if (my $conn = $self->{listen_sock}->accept) {
+            log('Connection from ',$conn->peerhost,':',$conn->peerport);
             $conn->setsockopt(IPPROTO_TCP, TCP_NODELAY, 1)
                 or die "setsockopt(TCP_NODELAY) failed:$!";
             my $env = {
@@ -66,6 +69,7 @@ sub accept_loop {
 sub _handle_response {
     my($self, $res, $conn) = @_;
 
+    log('Preparing response for code ',$res->[0]);
     my @lines = (
         "Date: @{[HTTP::Date::time2str()]}\015\012",
         "Server: $self->{server_software}\015\012",
@@ -79,10 +83,12 @@ sub _handle_response {
     unshift @lines, "HTTP/1.0 $res->[0] @{[ HTTP::Status::status_message($res->[0]) ]}\015\012";
     push @lines, "\015\012";
 
+    log('Writing ', scalar(@lines), ' lines of headers');
     $self->write_all($conn, join('', @lines), $self->{timeout})
         or return;
 
     if (defined $res->[2]) {
+        log('Writing ',length($res->[2]),' bytes of body');
         my $err;
         my $done;
         {
@@ -100,6 +106,7 @@ sub _handle_response {
             $err = $@;
         };
         if ($done) {
+            log('Done writing; closing connection');
             $conn->close();
 
         } else {
@@ -110,6 +117,7 @@ sub _handle_response {
             }
         }
     } else {
+        log('Setting up for delayed write');
         return Plack::Util::inline_object
             write => sub { $self->write_all($conn, $_[0], $self->{timeout}) },
             close => sub { $conn->close() };
